# Unless explicitly stated otherwise all files in this repository are licensed under the Apache-2.0 License.
# This product includes software developed at Datadog (https://www.datadoghq.com/).
# Copyright 2019-Present Datadog, Inc.


from datadog_api_client.model_utils import (
    ModelNormal,
    cached_property,
)


class SLOErrorBudgetRemainingData(ModelNormal):
    @cached_property
    def additional_properties_type(_):
        return (float,)

    def __init__(self, *args, **kwargs):
        """
        A mapping of threshold `timeframe` to the remaining error budget.
        """
        super().__init__(kwargs)

        self._check_pos_args(args)

    @classmethod
    def _from_openapi_data(cls, *args, **kwargs):
        """Helper creating a new instance from a response."""

        self = super(SLOErrorBudgetRemainingData, cls)._from_openapi_data(kwargs)

        self._check_pos_args(args)

        return self
